/*
 * Copyright 2016 - 2023 Gary Talent (gary@drinkingtea.net). All rights reserved.
 */

#pragma once

#include <ox/std/memory.hpp>

#include "context.hpp"
#include "module.hpp"

namespace nostalgia::foundation {

template<typename Context = foundation::Context>
ox::UPtr<Context> init(ox::UPtr<ox::FileSystem> &&fs, ox::CRStringView appName) noexcept {
	auto ctx = ox::make_unique<Context>();
	ctx->rom = std::move(fs);
	ctx->appName = appName;
	auto mods = modules();
	if (mods) {
		for (auto &mod : *mods) {
			// load type converters
			for (auto c : mod->converters()) {
				ctx->converters.emplace_back(c);
			}
		}
	}
	return ctx;
}

}
